% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/06_thermo2.R
\name{soln_saha}
\alias{soln_saha}
\title{Deviation of Ionization Fraction from 0.5}
\usage{
soln_saha(z)
}
\arguments{
\item{z}{Numeric. The redshift value.}
}
\value{
Numeric. \eqn{X_e - 0.5}.
}
\description{
Returns \eqn{X_e(z) - 0.5}, useful for finding the redshift at which the
ionization fraction equals 0.5 (e.g., via root-finding).
}
\examples{
soln_saha(1350)
}
